@@ -7,6 +7,7 @@ from matplotlib.collections import PatchCollection
 from matplotlib.colors import to_rgba_array
 from matplotlib.patches import Rectangle
 from matplotlib.pyplot import sca
+import matplotlib.markers as mmarkers
 
 from .controller import Controls, gogogo_controls, prep_scalars
 
@@ -23,7 +24,13 @@ from .helpers import (
     notebook_backend,
     update_datalim_from_bbox,
 )
-from .mpl_kwargs import Line2D_kwargs_list, imshow_kwargs_list, Text_kwargs_list, kwarg_popper
+from .mpl_kwargs import (
+    Line2D_kwargs_list,
+    imshow_kwargs_list,
+    Text_kwargs_list,
+    collection_kwargs_list,
+    kwarg_popper,
+)
 
 __all__ = [
     "interactive_plot",
@@ -403,7 +410,9 @@ def interactive_scatter(
     vmin=None,
     vmax=None,
     alpha=None,
+    marker=None,
     edgecolors=None,
+    facecolors=None,
     label=None,
     parametric=False,
     ax=None,
@@ -424,18 +433,21 @@ def interactive_scatter(
     x, y : function or float or array-like
         shape (n, ) for array-like. Functions must return the correct shape as well. If y is None
         then parametric must be True and the function for x must return x, y
-    c : array-like or list of colors or color, broadcastable
-        Must be broadcastable to x,y and any other plotting kwargs.
-        valid input to plt.scatter
+    c : array-like or list of colors or color or Callable
+        Valid input to plt.scatter or a function
     s : float, array-like, function, or index controls object
         valid input to plt.scatter, or a function
     alpha : float, None, or function(s), broadcastable
         Affects all scatter points. This will compound with any alpha introduced by
         the ``c`` argument
-    edgecolors : colorlike, broadcastable
+    marker : MarkerStyle, or Callable, optional
+        The marker style or a function returning marker styles.
+    edgecolor[s] : callable or valid argument to scatter
         passed through to scatter.
-    label : string(s) broadcastable
-        labels for the functions being plotted.
+    facecolor[s] : callable or valid argument to scatter
+        Valid input to plt.scatter, or a function
+    label : string
+        Passed through to Matplotlib
     parametric : boolean
         If True then the function expects to have only received a value for y and that that function will
         return an array for both x and y, or will return an array with shape (N, 2)
@@ -483,15 +495,22 @@ def interactive_scatter(
     else:
         stretch_y = False
 
+    # yanked from https://github.com/matplotlib/matplotlib/blob/bcc1ce8461f5b6e874baaaa02ef776d0243a4abe/lib/matplotlib/axes/_axes.py#L4271-L4273
+    facecolors = kwargs.pop("facecolor", facecolors)
+    edgecolors = kwargs.pop("edgecolor", edgecolors)
+
+    kwargs, collection_kwargs = kwarg_popper(kwargs, collection_kwargs_list)
+
     ipympl = notebook_backend()
     fig, ax = gogogo_figure(ipympl, ax)
     use_ipywidgets = ipympl or force_ipywidgets
     slider_formats = create_slider_format_dict(slider_formats)
 
     extra_ctrls = []
-    funcs, extra_ctrls, param_excluder = prep_scalars(kwargs, s=s, alpha=alpha)
+    funcs, extra_ctrls, param_excluder = prep_scalars(kwargs, s=s, alpha=alpha, marker=marker)
     s = funcs["s"]
     alpha = funcs["alpha"]
+    marker = funcs["marker"]
 
     controls, params = gogogo_controls(
         kwargs, controls, display_controls, slider_formats, play_buttons, extra_ctrls
@@ -509,7 +528,16 @@ def interactive_scatter(
         c_ = check_callable_xy(c, x_, y_, param_excluder(params), cache)
         s_ = check_callable_xy(s, x_, y_, param_excluder(params, "s"), cache)
         ec_ = check_callable_xy(edgecolors, x_, y_, param_excluder(params), cache)
+        fc_ = check_callable_xy(facecolors, x_, y_, param_excluder(params), cache)
         a_ = check_callable_alpha(alpha, param_excluder(params, "alpha"), cache)
+        marker_ = callable_else_value_no_cast(marker, param_excluder(params), cache)
+
+        if marker_ is not None:
+            if not isinstance(marker_, mmarkers.MarkerStyle):
+                marker_ = mmarkers.MarkerStyle(marker_)
+            path = marker_.get_path().transformed(marker_.get_transform())
+            scatter.set_paths((path,))
+
         if c_ is not None:
             try:
                 c_ = to_rgba_array(c_)
@@ -524,6 +552,8 @@ def interactive_scatter(
             scatter.set_facecolor(c_)
         if ec_ is not None:
             scatter.set_edgecolor(ec_)
+        if fc_ is not None:
+            scatter.set_facecolor(c_)
         if s_ is not None:
             if isinstance(s_, Number):
                 s_ = np.broadcast_to(s_, (len(x_),))
@@ -565,7 +595,9 @@ def interactive_scatter(
     c_ = check_callable_xy(c, x_, y_, p, {})
     s_ = check_callable_xy(s, x_, y_, param_excluder(params, "s"), {})
     ec_ = check_callable_xy(edgecolors, x_, y_, p, {})
+    fc_ = check_callable_xy(facecolors, x_, y_, p, {})
     a_ = check_callable_alpha(alpha, params, {})
+    marker_ = callable_else_value_no_cast(marker, p, {})
     scatter = ax.scatter(
         x_,
         y_,
@@ -574,9 +606,12 @@ def interactive_scatter(
         vmin=vmin,
         vmax=vmax,
         cmap=cmap,
+        marker=marker_,
         alpha=a_,
         edgecolors=ec_,
+        facecolors=fc_,
         label=label,
+        **collection_kwargs,
     )
     # this is necessary to make calls to plt.colorbar behave as expected
     sca(ax)
@@ -825,19 +860,19 @@ def interactive_axhline(
     )
 
     def update(params, indices, cache):
-        y_ = callable_else_value(y, param_excluder(params, 'y'), cache).item()
+        y_ = callable_else_value(y, param_excluder(params, "y"), cache).item()
         line.set_ydata([y_, y_])
-        xmin_ = callable_else_value(xmin, param_excluder(params, 'xmin'), cache).item()
-        xmax_ = callable_else_value(xmax, param_excluder(params, 'xmin'), cache).item()
+        xmin_ = callable_else_value(xmin, param_excluder(params, "xmin"), cache).item()
+        xmax_ = callable_else_value(xmax, param_excluder(params, "xmax"), cache).item()
         line.set_xdata([xmin_, xmax_])
         # TODO consider updating just the ydatalim here
 
     controls._register_function(update, fig, params)
     sca(ax)
     line = ax.axhline(
-        callable_else_value(y, param_excluder(params, 'y')).item(),
-        callable_else_value(xmin, param_excluder(params, 'xmin')).item(),
-        callable_else_value(xmax, param_excluder(params, 'xmin')).item()
+        callable_else_value(y, param_excluder(params, "y")).item(),
+        callable_else_value(xmin, param_excluder(params, "xmin")).item(),
+        callable_else_value(xmax, param_excluder(params, "xmax")).item(),
         **line_kwargs,
     )
     return controls
@@ -917,19 +952,19 @@ def interactive_axvline(
     )
 
     def update(params, indices, cache):
-        x_ = callable_else_value(x, param_excluder(params, 'x'), cache).item()
+        x_ = callable_else_value(x, param_excluder(params, "x"), cache).item()
         line.set_xdata([x_, x_])
-        ymin_ = callable_else_value(ymin, param_excluder(params, 'ymin'), cache).item()
-        ymax_ = callable_else_value(ymax, param_excluder(params, 'ymax'), cache).item()
+        ymin_ = callable_else_value(ymin, param_excluder(params, "ymin"), cache).item()
+        ymax_ = callable_else_value(ymax, param_excluder(params, "ymax"), cache).item()
         line.set_ydata([ymin_, ymax_])
         # TODO consider updating just the ydatalim here
 
     controls._register_function(update, fig, params)
     sca(ax)
     line = ax.axvline(
-        callable_else_value(x, param_excluder(params, 'x')).item(),
-        callable_else_value(ymin, param_excluder(params, 'ymin')).item(),
-        callable_else_value(ymax, param_excluder(params, 'ymax')).item(),
+        callable_else_value(x, param_excluder(params, "x")).item(),
+        callable_else_value(ymin, param_excluder(params, "ymin")).item(),
+        callable_else_value(ymax, param_excluder(params, "ymax")).item(),
         **line_kwargs,
     )
     return controls
